aboutsummaryrefslogtreecommitdiffstats
path: root/home/map_objects.asm
diff options
context:
space:
mode:
authordannye <33dannye@gmail.com>2024-09-29 10:50:46 -0500
committerdannye <33dannye@gmail.com>2024-09-29 10:50:46 -0500
commit716f8608c13fbee20b8fb71118e0691344098591 (patch)
treea69f3805e6e8e372a8fe9c064aa77d76efbed3a3 /home/map_objects.asm
parentIdentify more bit flags (#119) (diff)
downloadpokeyellow-716f8608c13fbee20b8fb71118e0691344098591.tar.gz
pokeyellow-716f8608c13fbee20b8fb71118e0691344098591.tar.xz
pokeyellow-716f8608c13fbee20b8fb71118e0691344098591.zip
Rename off-by-one wram labels
Diffstat (limited to 'home/map_objects.asm')
-rw-r--r--home/map_objects.asm14
1 files changed, 7 insertions, 7 deletions
diff --git a/home/map_objects.asm b/home/map_objects.asm
index 2359c7ca..c959f2db 100644
--- a/home/map_objects.asm
+++ b/home/map_objects.asm
@@ -71,11 +71,11 @@ IsItemInBag::
ret
IsSurfingPikachuInParty::
; set bit 6 of wd472 if true
; also calls Func_3467, which is a bankswitch to IsStarterPikachuInOurParty
- ld a, [wd472]
+ ld a, [wd471]
and $3f
- ld [wd472], a
+ ld [wd471], a
ld hl, wPartyMon1
ld c, PARTY_LENGTH
ld b, SURF
@@ -99,9 +99,9 @@ IsSurfingPikachuInParty::
cp b
jr nz, .noSurf
.hasSurf
- ld a, [wd472]
+ ld a, [wd471]
set 6, a
- ld [wd472], a
+ ld [wd471], a
.noSurf
pop hl
.notPikachu
@@ -119,9 +119,9 @@ Func_3467::
pop bc
pop hl
ret nc
- ld a, [wd472]
+ ld a, [wd471]
set 7, a
- ld [wd472], a
+ ld [wd471], a
ret
DisplayPokedex::
@@ -71,11 +71,11 @@ IsItemInBag::
ret
IsSurfingPikachuInParty::
-; set bit 6 of wd472 if true
+; set bit 6 of wd471 if true
; also calls Func_3467, which is a bankswitch to IsStarterPikachuInOurParty